@@ -3,8 +3,6 @@ import sys
 
 PY_VERSION = sys.version_info[:2]
 
-PY_34_PLUS = PY_VERSION >= (3, 4)
-PY_35_PLUS = PY_VERSION >= (3, 5)
 PY_36_PLUS = PY_VERSION >= (3, 6)
 
 if PY_VERSION > (3, 0):
@@ -25,6 +23,7 @@ if PY_VERSION > (3, 0):
     self_name = '__self__'
     from io import StringIO
     xrange = range
+    from itertools import zip_longest
 
 else:
 
@@ -44,6 +43,7 @@ else:
     self_name = 'im_self'
     from StringIO import StringIO
     xrange = xrange
+    from itertools import izip_longest as zip_longest
 
 try:
     from mock import call as mock_call
