@@ -1,14 +1,9 @@
-# Copyright (c) 2008-2013 Simplistix Ltd
-# See license.txt for license details.
-
 from testfixtures import Comparison as C, TempDirectory, compare
 from testfixtures.compat import PY2, PY3, exception_module
-from testfixtures.tests.sample1 import TestClassA, a_function
+from testfixtures.tests.sample1 import SampleClassA, a_function
 from unittest import TestCase
 import sys
 
-from .compat import py_33_plus, py_34_plus
-
 
 class AClass:
 
@@ -59,9 +54,9 @@ class TestC(TestCase):
         # of the correct type and order.
         r = a_function()
         self.assertEqual(r, (
-            C('testfixtures.tests.sample1.TestClassA'),
-            C('testfixtures.tests.sample1.TestClassB'),
-            C('testfixtures.tests.sample1.TestClassA'),
+            C('testfixtures.tests.sample1.SampleClassA'),
+            C('testfixtures.tests.sample1.SampleClassB'),
+            C('testfixtures.tests.sample1.SampleClassA'),
             ))
         # We also want to check specific parts of some
         # of the returned objects' attributes
@@ -138,8 +133,8 @@ class TestC(TestCase):
 
     def test_repr_class(self):
         self.assertEqual(
-            repr(C('testfixtures.tests.sample1.TestClassA')),
-            '<C:testfixtures.tests.sample1.TestClassA>'
+            repr(C('testfixtures.tests.sample1.SampleClassA')),
+            '<C:testfixtures.tests.sample1.SampleClassA>'
             )
 
     def test_repr_function(self):
@@ -150,9 +145,9 @@ class TestC(TestCase):
 
     def test_repr_instance(self):
         self.assertEqual(
-            repr(C(TestClassA('something'))),
+            repr(C(SampleClassA('something'))),
             "\n"
-            "  <C:testfixtures.tests.sample1.TestClassA>\n"
+            "  <C:testfixtures.tests.sample1.SampleClassA>\n"
             "  args:('something',)\n"
             "  </C>"
             )
@@ -187,18 +182,18 @@ class TestC(TestCase):
 
     def test_repr_class_and_vars(self):
         self.assertEqual(
-            repr(C(TestClassA, {'args': (1, )})),
+            repr(C(SampleClassA, {'args': (1,)})),
             "\n"
-            "  <C:testfixtures.tests.sample1.TestClassA>\n"
+            "  <C:testfixtures.tests.sample1.SampleClassA>\n"
             "  args:(1,)\n"
             "  </C>"
             )
 
     def test_repr_nested(self):
         self.assertEqual(
-            repr(C(TestClassA, y=C(AClass), z=C(BClass(1, 2)))),
+            repr(C(SampleClassA, y=C(AClass), z=C(BClass(1, 2)))),
             "\n"
-            "  <C:testfixtures.tests.sample1.TestClassA>\n"
+            "  <C:testfixtures.tests.sample1.SampleClassA>\n"
             "  y:<C:testfixtures.tests.test_comparison.AClass>\n"
             "  z:\n"
             "    <C:testfixtures.tests.test_comparison.BClass>\n"
@@ -225,7 +220,7 @@ class TestC(TestCase):
             self.fail('No exception raised!')
 
     def test_repr_failed_all_reasons_in_one(self):
-        if py_34_plus:
+        if PY3:
             expected = (
                 "\n  <C(failed):testfixtures.tests.test_com[79 chars] </C>"
                 " != <AClass>",
@@ -252,7 +247,7 @@ class TestC(TestCase):
             self.fail('No exception raised!')
 
     def test_repr_failed_not_in_other(self):
-        if py_34_plus:
+        if PY3:
             expected = (
                 "\n  <C(failed):testfixtures.tests.test_com[39 chars] </C>"
                 " != <AClass>",
@@ -279,7 +274,7 @@ class TestC(TestCase):
 
     def test_repr_failed_not_in_self_strict(self):
         # use single element tuple to check %
-        if py_34_plus:
+        if PY3:
             expected = (
                 "\n  <C(failed):testfixtures.tests.test_com[44 chars] </C>"
                 " != <AClass>",
@@ -303,7 +298,7 @@ class TestC(TestCase):
             self.fail('No exception raised!')
 
     def test_repr_failed_not_in_self_not_strict(self):
-        if py_34_plus:
+        if PY3:
             expected = (
                 "\n  <C(failed):testfixtures.tests.test_com[39 chars] </C>"
                 " != <AClass>",
@@ -442,44 +437,44 @@ class TestC(TestCase):
 
     def test_first(self):
         self.assertEqual(
-            C('testfixtures.tests.sample1.TestClassA'),
-            TestClassA()
+            C('testfixtures.tests.sample1.SampleClassA'),
+            SampleClassA()
             )
 
     def test_second(self):
         self.assertEqual(
-            TestClassA(),
-            C('testfixtures.tests.sample1.TestClassA'),
+            SampleClassA(),
+            C('testfixtures.tests.sample1.SampleClassA'),
             )
 
     def test_not_same_first(self):
         self.assertNotEqual(
             C('datetime'),
-            TestClassA()
+            SampleClassA()
             )
 
     def test_not_same_second(self):
         self.assertNotEqual(
-            TestClassA(),
+            SampleClassA(),
             C('datetime')
             )
 
     def test_object_supplied(self):
         self.assertEqual(
-            TestClassA(1),
-            C(TestClassA(1))
+            SampleClassA(1),
+            C(SampleClassA(1))
             )
 
     def test_class_and_vars(self):
         self.assertEqual(
-            TestClassA(1),
-            C(TestClassA, {'args': (1, )})
+            SampleClassA(1),
+            C(SampleClassA, {'args': (1,)})
             )
 
     def test_class_and_kw(self):
         self.assertEqual(
-            TestClassA(1),
-            C(TestClassA, args=(1, ))
+            SampleClassA(1),
+            C(SampleClassA, args=(1,))
             )
 
     def test_class_and_vars_and_kw(self):
@@ -491,15 +486,15 @@ class TestC(TestCase):
     def test_object_and_vars(self):
         # vars passed are used instead of the object's
         self.assertEqual(
-            TestClassA(1),
-            C(TestClassA(), {'args': (1, )})
+            SampleClassA(1),
+            C(SampleClassA(), {'args': (1,)})
             )
 
     def test_object_and_kw(self):
         # kws passed are used instead of the object's
         self.assertEqual(
-            TestClassA(1),
-            C(TestClassA(), args=(1, ))
+            SampleClassA(1),
+            C(SampleClassA(), args=(1,))
             )
 
     def test_object_not_strict(self):
@@ -608,7 +603,7 @@ class TestC(TestCase):
         self.assertEqual(C(X, x=1, strict=False), x)
 
     def test_no___dict___not_strict_different(self):
-        if py_34_plus:
+        if PY3:
             expected = (
                 "\n  <C(failed):testfixtures.tests.test_com[42 chars] </C>"
                 " != <X>",
@@ -735,7 +730,7 @@ class TestC(TestCase):
         NoName.__name__ = ''
         NoName.__module__ = ''
         c = C(NoName)
-        if py_33_plus:
+        if PY3:
             expected = "<C:<class '.TestC.test_no_name.<locals>.NoName'>>"
         else:
             expected = "<C:<class '.'>>"
